espn_game_id: Get box score data for the players, given a gameId

espn_game_idR Documentation

Get box score data for the players, given a gameId

Description

Requires use of ESPN oriented team names, found in locally saved file (ids.csv)

Usage

espn_game_id

Arguments

espn_game_id

(str) The eight digit gameId for the desired game

Format

An object of class numeric of length 1.

Value

A dataframe with player-level box-score information


dhutexas/collegehoops documentation built on April 1, 2022, 3:44 a.m.