get_box_score_team: Get box score data for the teams, given a gameId

View source: R/get_box_score_team.R

get_box_score_teamR Documentation

Get box score data for the teams, given a gameId

Description

Requires use of ESPN oriented team names, found in locally saved file (ids.csv)

Usage

get_box_score_team(espn_game_id)

Arguments

espn_game_id

(str) The eight digit gameId for the desired game

Value

A dataframe with team-level box-score information


dhutexas/collegehoops documentation built on April 1, 2022, 3:44 a.m.